@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 def quando():
-    print('30 de março a 01 de abril --> #naoehmentira')
+    print('30 de março a 01 de abril de 2018 -> #naoehmentira')
 
 
 def onde():
@@ -10,4 +10,4 @@ def onde():
 
 
 def informacoes():
-    print('http://pythonsudeste.org')
+    print('Acesse o site: http://pythonsudeste.org')
